# Curated API Reference

This is a manually curated API reference;
while most objects are part of the ``usim`` namespace,
the documentation is split into various topics.

Use [autodoc directives](http://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html)
to automatically generate documentations of objects from their docstrings.
In addition, μSim uses the
[autodoc trio extension](https://sphinxcontrib-trio.readthedocs.io/en/latest/)
which allows usage annotations, such as ``:async:`` or ``:with: foo``.
